==============================================================================
 Sage: Open Source Mathematics Software: Giac integration
==============================================================================

This pip-installable source distribution ``sagemath-giac`` is a small
optional distribution for use with ``sagemath-standard``.

It provides a Cython interface to the ``libgiac`` library for the
purpose of symbolic integration and certain Groebner basis
calculations.
